A vector containing levels of a factor, or the number of levels.
contrasts
A logical value indicating whether contrasts should be computed.
Value
A matrix with n rows and n-1 columns for contr.ordinal,
a matrix with n rows and n columns for contr.dummy
and a vector of length n for contr.metric.
Details
contr.dummy is standard dummy-coding, contr.metric has the same
effect like as.numeric (makes sense of course only for ordered variables).
contr.ordinal computes contrasts for ordinal variables.
References
Hechenbichler K. and Schliep K.P. (2004) Weighted k-Nearest-Neighbor Techniques and Ordinal Classification, Discussion Paper 399, SFB 386, Ludwig-Maximilians University Munich
(http://www.stat.uni-muenchen.de/sfb386/papers/dsp/paper399.ps)