A logical value. If TRUE the training procedure for selecting optimal values of k and kernel is performed.
k
Number or maximal number of neighbors considered, dependent of choice for train.
...
Further arguments passed to or from other methods.
Value
A matrix, containing the mean and variance of the misclassification
error, the absolute and the squared distances.
References
Hechenbichler K. and Schliep K.P. (2004) Weighted k-Nearest-Neighbor Techniques and Ordinal Classification, Discussion Paper 399, SFB 386, Ludwig-Maximilians University Munich
(http://www.stat.uni-muenchen.de/sfb386/papers/dsp/paper399.ps)