Learn R Programming

kknn (version 1.2-2)

miete: Munich Rent Standard Database (1994)

Description

Many german cities compose so-called rent standards to make a decision making instrument available to tenants, landlords, renting advisory boards and experts. The rent standards are used in particular for the determination of the local comparative rent (i.e. net rent as a function of household size, equipment, year of construction, etc.). For the composition of the rent standards, a representative random sample is drawn from all relevant households, and the interesting data are determined by interviewers by means of questionnaires. The dataset contains the data of 1082 households interviewed for the munich rent standard 1994.

Usage

data(miete)

Arguments

source

Fahrmeir, L., Kuenstler, R., Pigeot, I. und Tutz, G. (1997): Statistik: der Weg zur Datenanalyse, Springer, Berlin. http://www.stat.uni-muenchen.de/service/datenarchiv The data were converted to R format by klaus.schliep@gmail.com.

Examples

Run this code
data(miete)
str(miete)

Run the code above in your browser using DataLab